# cherwell_pydantic_api
## a pythonic, asyncio connector for the Cherwell CSM API with full usage of Pydantic types

There are a few existing python modules for the Cherwell API but they appear to be too basic for my requirements, therefore this is my attempt.

Pydantic models are used throughout. Furthermore, Pydantic models are also generated for Business Objects.
